Index: chrome/browser/views/first_run_search_engine_view.h |
=================================================================== |
--- chrome/browser/views/first_run_search_engine_view.h (revision 49796) |
+++ chrome/browser/views/first_run_search_engine_view.h (working copy) |
@@ -85,9 +85,10 @@ |
public: |
// |observer| is the FirstRunView that waits for us to pass back a search |
// engine choice; |profile| allows us to get the set of imported search |
// engines, and display the KeywordEditorView on demand. |
FirstRunSearchEngineView(SearchEngineSelectionObserver* observer, |
- Profile* profile); |
+ Profile* profile, bool randomize); |
virtual ~FirstRunSearchEngineView(); |
@@ -133,6 +134,9 @@ |
bool text_direction_is_rtl_; |
+ // If logos are to be displayed in random order. Used for UX testing. |
+ bool randomize_; |
+ |
// UI elements: |
// Text above the first horizontal separator |
views::Label* title_label_; |
@@ -85,9 +85,10 @@ |
// |observer| is the FirstRunView that waits for us to pass back a search |
// engine choice; |profile| allows us to get the set of imported search |
- // engines, and display the KeywordEditorView on demand. |
+ // engines, and display the KeywordEditorView on demand; |randomize| |
+ // is true if logos are to be displayed in random order. |
FirstRunSearchEngineView(SearchEngineSelectionObserver* observer, |